=====
Usage
=====

After following :ref:`installation:Installation` instructions,
to use fwd in a project:

    >>> import fwd

.. note::
   See :ref:`package docs <fwd:fwd package>` section for documentation.
